@@ -174,6 +174,7 @@ class PointCsvReader:
         y_field,
         geopoint=None,
         group_field='species_name',
+        encoding='utf8',
     ):
         """Constructor for a Point CSV retriever.
 
@@ -188,6 +189,7 @@ class PointCsvReader:
             geopoint (:obj:`str`): The field name of the column containing geopoint
                 data.
             group_field (:obj:`str`): The name of the field to use for grouping points.
+            encoding (str): The encoding to use when opening the file.
         """
         self.filename = filename
         self.file = None
@@ -199,6 +201,7 @@ class PointCsvReader:
         self.group_field = group_field
         self._next_points = []
         self._curr_val = None
+        self.encoding = encoding
 
     # .......................
     def __enter__(self):
@@ -275,7 +278,7 @@ class PointCsvReader:
     # .......................
     def open(self):
         """Open the file and initialize."""
-        self.file = open(self.filename, 'r')
+        self.file = open(self.filename, 'r', encoding=self.encoding)
         temp_lines = []
         try:
             for _ in range(3):
@@ -297,7 +300,15 @@ class PointCsvWriter:
     """Class for writing Points to a CSV file."""
 
     # .......................
-    def __init__(self, filename, fields, write_headers=True, mode='w', **kwargs):
+    def __init__(
+        self,
+        filename,
+        fields,
+        write_headers=True,
+        mode='w',
+        encoding='utf8',
+        **kwargs
+    ):
         """Constructor for writing points to csv file.
 
         Args:
@@ -305,6 +316,7 @@ class PointCsvWriter:
             fields (:obj:`list`): A list of fields to include in the csv headers.
             write_headers (:obj:`bool`): Should headers be written.
             mode (:obj:`str`): File write mode.
+            encoding (str): The encoding to use when writing data.
             **kwargs (:obj:`dict`): Keyword parameters that will be passed to the
                 DictWriter instance from the csv module.
         """
@@ -312,6 +324,7 @@ class PointCsvWriter:
         self.file = None
         self.writer = None
         self.field_names = fields
+        self.encoding = encoding
         self.kwargs = kwargs
         self.write_headers = write_headers
         self.file_mode = mode
@@ -343,7 +356,7 @@ class PointCsvWriter:
     # .......................
     def open(self):
         """Open file for writing."""
-        self.file = open(self.filename, self.file_mode)
+        self.file = open(self.filename, self.file_mode, encoding=self.encoding)
         self.writer = csv.DictWriter(self.file, self.field_names, **self.kwargs)
         if self.write_headers:
             self.writer.writeheader()
@@ -494,8 +507,10 @@ class PointDwcaReader:
         Raises:
             StopIteration: Raised when there are no additional objects.
         """
-        for point_row in self.reader:
+        more_rows = True
+        while more_rows:
             try:
+                point_row = next(self.reader)
                 point_dict = {
                     term: self.fields[term](point_row) for term in self.fields.keys()
                 }
@@ -514,10 +529,16 @@ class PointDwcaReader:
                         return tmp
                     self._curr_val = test_val
                 self._next_points.append(pt)
+            except IndexError:
+                pass
             except KeyError:
                 pass
             except TypeError:
                 pass
+            except StopIteration:
+                more_rows = False
+            except csv.Error:
+                pass
 
         if self._next_points:
             tmp = self._next_points
