@@ -3,7 +3,10 @@ from . import build_grid
 from . import calculate_pam_stats
 from . import convert_csv_to_lmm
 from . import convert_lmm_to_csv
+from . import create_point_heatmap
 from . import create_rare_species_model
+from . import create_scatter_plot
+from . import create_stat_heatmap
 from . import create_tree_matrix
 from . import encode_layers
 from . import mcpa_run
@@ -19,7 +22,10 @@ __all__.extend(build_grid.__all__)
 __all__.extend(calculate_pam_stats.__all__)
 __all__.extend(convert_csv_to_lmm.__all__)
 __all__.extend(convert_lmm_to_csv.__all__)
+__all__.extend(create_point_heatmap.__all__)
 __all__.extend(create_rare_species_model.__all__)
+__all__.extend(create_scatter_plot.__all__)
+__all__.extend(create_stat_heatmap.__all__)
 __all__.extend(create_tree_matrix.__all__)
 __all__.extend(encode_layers.__all__)
 __all__.extend(mcpa_run.__all__)
