@@ -83,6 +83,11 @@ def build_parser():
             'a species header key, an x header key, and a y header key.'
         ),
     )
+    parser.add_argument(
+        '--species_list_filename',
+        type=str,
+        help='File location to write list of species seen (after wrangling).'
+    )
 
     parser.add_argument(
         'out_dir',
@@ -98,6 +103,10 @@ def cli():
     parser = build_parser()
     args = _process_arguments(parser, 'config_file')
 
+    # Default key field is 'species_name'
+    if args.key_field is None:
+        args.key_field = ['species_name']
+
     # Establish functions for getting writer key and filename
     writer_key_func = get_writer_key_from_fields_func(*tuple(args.key_field))
     writer_filename_func = get_writer_filename_func(args.out_dir)
@@ -131,6 +140,8 @@ def cli():
                 with open(wranglers_fn, mode='rt') as in_json:
                     wranglers = wrangler_factory.get_wranglers(json.load(in_json))
                 occurrence_processor.process_reader(reader, wranglers)
+        if args.species_list_filename:
+            occurrence_processor.write_species_list(args.species_list_filename)
 
 
 # .....................................................................................
